#
# spec file for package mupen64plus
#
# Copyright (c) 2013 Guido Berhoerster <gber@opensuse.org>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           mupen64plus
Version:        2.0
Release:        2.2
Summary:        Plugin-Based Nintendo 64 Emulator
License:        GPL-2.0+
Group:          System/Emulators/Other
Url:            http://code.google.com/p/mupen64plus/
BuildRequires:  gcc-c++
BuildRequires:  lirc-devel
BuildRequires:  binutils-devel
BuildRequires:  boost-devel
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(sdl)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(zlib)
Source:         http://mupen64plus.googlecode.com/files/mupen64plus-bundle-src-%{version}.tar.gz
Source100:      %{name}-rpmlintrc
# PATCH-FIX-OPENSUSE mupen64plus-fix-cflags.patch gber@opensuse.org -- Fix the Makefiles not to hardcode optimizations
Patch0:         mupen64plus-fix-cflags.patch
# PATCH-FIX-OPENSUSE mupen64plus-use-system-font.patch gber@opensuse.org -- Use system DejaVu font rather than an inlined copy of it
Patch1:         mupen64plus-use-system-font.patch
# PATCH-FIX-UPSTREAM mupen64plus-fix-missing-includes.patch gber@opensuse.org -- Fix missing includes
Patch2:         mupen64plus-fix-missing-includes.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Mupen64Plus is a plugin-based N64 emulator which is capable of accurately
playing many games. It includes four MIPS R4300 CPU emulators, with dynamic
recompilers for 32-bit x86 and 64-bit amd64 systems.  It supports plugins for
audio, graphical rendering (RDP), the signal co-processor (RSP), and input.

%package -n libmupen64plus2
Summary:        Shared Library Interface to the Mupen64plus Nintendo 64 Emulator
Group:          System/Emulators/Other
Requires:       dejavu

%description -n libmupen64plus2
Mupen64Plus is a plugin-based N64 emulator which is capable of accurately
playing many games. It includes four MIPS R4300 CPU emulators, with dynamic
recompilers for 32-bit x86 and 64-bit amd64 systems.  It supports plugins for
audio, graphical rendering (RDP), the signal co-processor (RSP), and input.

This package contains the shared library interface for Mupen64plus frontends.

%package -n libmupen64plus-devel
Summary:        Include Files for Mupen64plus Development
Group:          Development/Libraries/C and C++
Requires:       libmupen64plus2 = %{version}

%description -n libmupen64plus-devel
This package contains all necessary include files to develop frontends against
the Mupen64plus shared library interface.

%package ui-console
Summary:        Command Line Frontend for the Mupen64plus Nintendo 64 Emulator
Group:          System/Emulators/Other
Requires:       libmupen64plus2
Requires:       mupen64plus-plugin-audio
Requires:       mupen64plus-plugin-input
Requires:       mupen64plus-plugin-rsp
Requires:       mupen64plus-plugin-video

%description ui-console
Mupen64Plus is a plugin-based N64 emulator which is capable of accurately
playing many games.

This package contains a command line frontend.

%package plugin-audio-sdl
Summary:        SDL Audio Plugin for the Mupen64plus Nintendo 64 Emulator
Group:          System/Emulators/Other
Provides:       mupen64plus-plugin-audio

%description plugin-audio-sdl
This package contains the SDL audio plugin for the Mupen64plus Nintendo 64
Emulator.

%package plugin-input-sdl
Summary:        SDL Input Plugin for the Mupen64plus Nintendo 64 Emulator
Group:          System/Emulators/Other
Provides:       mupen64plus-plugin-input

%description plugin-input-sdl
This package contains the SDL input plugin for the Mupen64plus Nintendo 64
Emulator. It has LIRC Infrared remote control interface and Rumble Pak support.

%package plugin-rsp-hle
Summary:        RSP High-Level Emulation Plugin For the Mupen64plus Nintendo 64 Emulator
Group:          System/Emulators/Other
Provides:       mupen64plus-plugin-rsp

%description plugin-rsp-hle
This package contains the RSP High-Level emulation plugin for the Mupen64plus
Nintendo 64 Emulator.

%package plugin-video-rice
Summary:        Rice Video Plugin for the Mupen64plus Nintendo 64 Emulator
Group:          System/Emulators/Other
Provides:       mupen64plus-plugin-video

%description plugin-video-rice
This package contains the Rice Video Plugin for the Mupen64plus Nintendo 64
Emulator. It provides a high-level graphics emulation with support for
high-resolution texture support.

%package plugin-video-glide64mk2
Summary:        Glide64mk2 Video Plugin for the Mupen64plus Nintendo 64 Emulator
Group:          System/Emulators/Other
Provides:       mupen64plus-plugin-video

%description plugin-video-glide64mk2
This package contains the Glide64mk2 Video Plugin for the Mupen64plus
Nintendo 64 Emulator which provides high-level graphics emulation.

%prep
%setup -q -n %{name}-bundle-src-%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1

%build
make %{?_smp_mflags} -C source/mupen64plus-core/projects/unix all \
    OPTFLAGS="%{optflags}" \
%ifnarch x86_64
    NO_ASM=1 \
%endif
    PIC=1 \
    PREFIX=%{_prefix} \
    SHAREDIR=%{_datadir}/mupen64plus2 \
    LIBDIR=%{_libdir} \
    DEBUGGER=1 \
    LIRC=1 \
    V=1
make %{?_smp_mflags} -C source/mupen64plus-ui-console/projects/unix all \
    OPTFLAGS="%{optflags}" \
    PIC=1 \
    PREFIX=%{_prefix} \
    LIBDIR=%{_libdir} \
    SHAREDIR=%{_datadir}/mupen64plus2 \
    COREDIR=%{_libdir}/ \
    PLUGINDIR=%{_libdir}/mupen64plus2 \
    V=1
make %{?_smp_mflags} -C source/mupen64plus-audio-sdl/projects/unix all \
    OPTFLAGS="%{optflags}" \
    PIC=1 \
    PREFIX=%{_prefix} \
    LIBDIR=%{_libdir} \
    PLUGINDIR=%{_libdir}/mupen64plus2 \
    V=1
make %{?_smp_mflags} -C source/mupen64plus-input-sdl/projects/unix all \
    OPTFLAGS="%{optflags}" \
    PIC=1 \
    PREFIX=%{_prefix} \
    LIBDIR=%{_libdir} \
    SHAREDIR=%{_datadir}/mupen64plus2 \
    PLUGINDIR=%{_libdir}/mupen64plus2 \
    V=1
make %{?_smp_mflags} -C source/mupen64plus-rsp-hle/projects/unix all \
    OPTFLAGS="%{optflags}" \
    PIC=1 \
    PREFIX=%{_prefix} \
    LIBDIR=%{_libdir} \
    PLUGINDIR=%{_libdir}/mupen64plus2 \
    V=1
make %{?_smp_mflags} -C source/mupen64plus-video-rice/projects/unix all \
%ifnarch x86_64
    OPTFLAGS="%{optflags}" \
    NO_ASM=1 \
%else
    OPTFLAGS="%{optflags} -msse" \
%endif
    PREFIX=%{_prefix} \
    LIBDIR=%{_libdir} \
    SHAREDIR=%{_datadir}/mupen64plus2 \
    PLUGINDIR=%{_libdir}/mupen64plus2 \
    PIC=1 \
    V=1
make %{?_smp_mflags} -C source/mupen64plus-video-glide64mk2/projects/unix all \
%ifnarch x86_64
    OPTFLAGS="%{optflags} -DNOSSE" \
    NO_ASM=1 \
%else
    OPTFLAGS="%{optflags} -mmmx -msse" \
%endif
    PREFIX=%{_prefix} \
    LIBDIR=%{_libdir} \
    SHAREDIR=%{_datadir}/mupen64plus2 \
    PLUGINDIR=%{_libdir}/mupen64plus2 \
    PIC=1 \
    V=1

%install
# mupen64plus-core still builds from the install target
make -C source/mupen64plus-core/projects/unix install \
    OPTFLAGS="%{optflags}" \
%ifnarch x86_64
    NO_ASM=1 \
%endif
    DESTDIR="%{buildroot}" \
    PREFIX=%{_prefix} \
    SHAREDIR=%{_datadir}/mupen64plus2 \
    LIBDIR=%{_libdir} \
    DEBUGGER=1 \
    LIRC=1 \
    INSTALL_STRIP_FLAG= \
    V=1
(
    cd %{buildroot}%{_libdir}
    ln -s libmupen64plus.so.2.0.0 libmupen64plus.so
)
make -C source/mupen64plus-ui-console/projects/unix install \
    DESTDIR="%{buildroot}" \
    PREFIX=%{_prefix} \
    LIBDIR=%{_libdir} \
    SHAREDIR=%{_datadir}/mupen64plus2 \
    COREDIR=%{_libdir}/ \
    PLUGINDIR=%{_libdir}/mupen64plus2 \
    INSTALL_STRIP_FLAG= \
    V=1
rm %{buildroot}%{_datadir}/mupen64plus2/font.ttf
make -C source/mupen64plus-audio-sdl/projects/unix install \
    DESTDIR="%{buildroot}" \
    PREFIX=%{_prefix} \
    LIBDIR=%{_libdir} \
    PLUGINDIR=%{_libdir}/mupen64plus2 \
    INSTALL_STRIP_FLAG= \
    V=1
make -C source/mupen64plus-input-sdl/projects/unix install \
    DESTDIR="%{buildroot}" \
    PREFIX=%{_prefix} \
    LIBDIR=%{_libdir} \
    SHAREDIR=%{_datadir}/mupen64plus2 \
    PLUGINDIR=%{_libdir}/mupen64plus2 \
    INSTALL_STRIP_FLAG= \
    V=1
make -C source/mupen64plus-rsp-hle/projects/unix install \
    DESTDIR="%{buildroot}" \
    PREFIX=%{_prefix} \
    LIBDIR=%{_libdir} \
    PLUGINDIR=%{_libdir}/mupen64plus2 \
    INSTALL_STRIP_FLAG= \
    V=1
make -C source/mupen64plus-video-rice/projects/unix install \
    DESTDIR="%{buildroot}" \
    PREFIX=%{_prefix} \
    LIBDIR=%{_libdir} \
    SHAREDIR=%{_datadir}/mupen64plus2 \
    PLUGINDIR=%{_libdir}/mupen64plus2 \
    INSTALL_STRIP_FLAG= \
    V=1
make -C source/mupen64plus-video-glide64mk2/projects/unix install \
    DESTDIR="%{buildroot}" \
    PREFIX=%{_prefix} \
    LIBDIR=%{_libdir} \
    SHAREDIR=%{_datadir}/mupen64plus2 \
    PLUGINDIR=%{_libdir}/mupen64plus2 \
    INSTALL_STRIP_FLAG= \
    V=1
chmod -R 0755 %{buildroot}%{_libdir}

%post -n libmupen64plus2 -p /sbin/ldconfig

%postun -n libmupen64plus2 -p /sbin/ldconfig

%clean
rm -rf %{buildroot}

%files -n libmupen64plus2
%defattr(-,root,root,-)
%doc source/mupen64plus-core/{LICENSES,README,RELEASE}
%dir %{_datadir}/mupen64plus2
%dir %{_libdir}/mupen64plus2
%{_libdir}/libmupen64plus.so.*
%{_datadir}/mupen64plus2/mupen64plus.cht
%{_datadir}/mupen64plus2/mupencheat.txt
%{_datadir}/mupen64plus2/mupen64plus.ini

%files -n libmupen64plus-devel
%defattr(-,root,root,-)
%{_includedir}/mupen64plus
%{_libdir}/libmupen64plus.so

%files ui-console
%defattr(-,root,root,-)
%doc source/mupen64plus-ui-console/{LICENSES,README,RELEASE}
%doc %{_mandir}/man6/mupen64plus.6*
%{_bindir}/mupen64plus

%files plugin-audio-sdl
%defattr(-,root,root,-)
%doc source/mupen64plus-audio-sdl/{LICENSES,RELEASE}
%{_libdir}/mupen64plus2/mupen64plus-audio-sdl.so

%files plugin-input-sdl
%defattr(-,root,root,-)
%doc source/mupen64plus-input-sdl/{AUTHORS,COPYING,LICENSES,README,RELEASE}
%{_datadir}/mupen64plus2/InputAutoCfg.ini
%{_libdir}/mupen64plus2/mupen64plus-input-sdl.so

%files plugin-rsp-hle
%defattr(-,root,root,-)
%doc source/mupen64plus-rsp-hle/{LICENSES,RELEASE}
%{_libdir}/mupen64plus2/mupen64plus-rsp-hle.so

%files plugin-video-rice
%defattr(-,root,root,-)
%doc source/mupen64plus-video-rice/{LICENSES,README,RELEASE}
%{_datadir}/mupen64plus2/RiceVideoLinux.ini
%{_libdir}/mupen64plus2/mupen64plus-video-rice.so

%files plugin-video-glide64mk2
%defattr(-,root,root,-)
%doc source/mupen64plus-video-glide64mk2/doc/{fxt1-license,gpl-license}
%{_datadir}/mupen64plus2/Glide64mk2.ini
%{_libdir}/mupen64plus2/mupen64plus-video-glide64mk2.so

%changelog
* Thu Oct 31 2013 gber@opensuse.org
- add mupen64plus-fix-missing-includes.patch in order to fix
  missing includes
* Tue Jul  9 2013 gber@opensuse.org
- update to version 2.0
* Wed Jun  5 2013 gber@opensuse.org
- disable SSE usage in Glide64mk2 plugin
- enable SSE/MMX usage for x86_64 arch
* Wed Jun  5 2013 gber@opensuse.org
- build the new Glide64mk2 plugin
* Tue Jun  4 2013 gber@opensuse.org
- update to version 1.99.99.2 (2.0-rc2)
  - see
    https://groups.google.com/d/msg/mupen64plus/i6dkYjaAv2I/gQvRAzSVHYoJ
- removed obsolete mupen64plus-fix-float-parsing.patch and
  mupen64plus-fix-debugger-off-by-one-bug.patch
- rebased and renamed mupen64plus-fix-makefiles.patch to
  mupen64plus-fix-cflags.patch
* Wed May 16 2012 gber@opensuse.org
- added mupen64plus-fix-debugger-off-by-one-bug.patch which fixes
  an off-by-one bug in the debugger (backported from upstream hg)
* Tue May 15 2012 gber@opensuse.org
- disable all asm code
- always build PIC
* Sun May  6 2012 gber@opensuse.org
- sync macros between all and install targets
- build debugger
- added mupen64plus-fix-float-parsing.patch in order to use sscanf
  for reading floating-point values in config file instead of
  character parsing, so that other locales with commas instead of
  periods for decimal separator can be supported (backported from
  upstream git)
* Sat May  5 2012 gber@opensuse.org
- update to version 1.99.5
  * Audio-SDL Plugin
    + added version number to SDL-audio plugin config parameters,
    to support future changes
    + updated audio plugin for new Mupen64plus 2.0 API versioning
    scheme
    + makefile fixes and improvements
  * Console-UI Front End Application
    + new option to disable internal core speed limiter (for
    benchmarking)
    + updated Console-UI front-end for new Mupen64plus 2.0 API
    versioning
    + added config version number for UI-Console section
    + makefile fixes and improvements
  * Core Emulator Library
    + new feature: support for N64 internal real-time clock
    + use X-Scale's PIF-CIC algorithm instead of the hard-coded
    challenge-response pairs
    + new config parameter for path to save SRAM/EEPROM/MPK files,
    so they can be separated from emulator snapshots
    + updated core for new Mupen64plus 2.0 API versioning scheme
    + split core configuration data into 2 sections: Core and
    CoreEvents. Added version numbers and upgrade handling to
    both
    + accurately emulate the RSP DMA operation (from Bobby Smiles)
    + many makefile fixes and improvements
    + bugfixes
  * Input-SDL Plugin
    + improved input setup behavior (auto-config) to make some use
    cases more friendly
    + updated input plugin for new Mupen64plus 2.0 API versioning
    scheme
    + added version number to SDL Input plugin parameters
    + add new parameter for mouse sensitivity, handle mouse
    movement differently so mouse is easier to use as controller
    + new auto-configuration for several controllers
    + bugfixes
    + makefile fixes and improvements
  * Rice Video Plugin
    + hires texture loading: support for 8-bit PNG images
    + new config option for forcing vertical sync
    + check OpenGL attributes after creating video window and
    report any that failed to set
    + updated video plugin for new Mupen64plus 2.0 API versioning
    scheme
    + update to Video API version 2.1.0.
    + bugfixes
    + makefile fixes, improvements, and code cleanups
  * RSP-HLE Plugin
    + handle JPEG decompression, used in Ogre Battle 64 and Pokemon
    Stadium
    + updated RSP plugin for new Mupen64plus 2.0 API versioning
    scheme
    + bugfixes
    + many makefile fixes and improvements
- adapted and renamed mupen64plus-1.99.4-fix-makefiles.patch to
  mupen64plus-fix-makefiles.patch
- renamed mupen64plus-1.99.3-use-system-font.patch to
  mupen64plus-use-system-font.patch
* Sat Dec 25 2010 guido+packman@berhoerster.name
- update to version 1.99.4
  * Console-UI Front End Application
    + bugfixes
  * Core Emulator Library
    + bugfixes
    + new re-entrant R4300 disassembler
  * Audio-SDL Plugin
    + bugfixes
  * Input-SDL Plugin
    + bugfixes
    + many new joystick auto-configurations
  * Rice Video Plugin
    + anisotropic filtering
    + trilinear filtering
    + mipmaps
    + support for anti-aliasing (GL_MULTISAMPLE)
    + bugfixes
  * RSP-HLE Plugin
    + bugfixes
* Mon Jul 19 2010 guido+packman@berhoerster.name
- recompressed source tarball
* Mon Jul 19 2010 guido+packman@berhoerster.name
- inintial packaging of mupen64plus
